package com.cn.fdapfe.biz.mapper;

import java.util.List;
import com.cn.fdapfe.biz.domain.Workflow;
import com.cn.fdapfe.biz.domain.WorkflowNode;

/**
 * 流程任务Mapper接口
 * 
 * @author Allen
 * @date 2025-03-07
 */
public interface WorkflowMapper 
{
    /**
     * 查询流程任务
     * 
     * @param id 流程任务主键
     * @return 流程任务
     */
    public Workflow selectWorkflowById(Long id);

    /**
     * 查询流程任务列表
     * 
     * @param workflow 流程任务
     * @return 流程任务集合
     */
    public List<Workflow> selectWorkflowList(Workflow workflow);

    /**
     * 新增流程任务
     * 
     * @param workflow 流程任务
     * @return 结果
     */
    public int insertWorkflow(Workflow workflow);

    /**
     * 修改流程任务
     * 
     * @param workflow 流程任务
     * @return 结果
     */
    public int updateWorkflow(Workflow workflow);

    /**
     * 删除流程任务
     * 
     * @param id 流程任务主键
     * @return 结果
     */
    public int deleteWorkflowById(Long id);

    /**
     * 批量删除流程任务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWorkflowByIds(Long[] ids);

    /**
     * 批量删除流程节点
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWorkflowNodeByTaskIds(Long[] ids);
    
    /**
     * 批量新增流程节点
     * 
     * @param workflowNodeList 流程节点列表
     * @return 结果
     */
    public int batchWorkflowNode(List<WorkflowNode> workflowNodeList);
    

    /**
     * 通过流程任务主键删除流程节点信息
     * 
     * @param id 流程任务ID
     * @return 结果
     */
    public int deleteWorkflowNodeByTaskId(Long id);
}
