package com.cn.fdapfe.biz.service.impl;

import java.util.List;
import java.util.Map;

import com.cn.fdapfe.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.cn.fdapfe.biz.mapper.FaultDiagnosisModelMapper;
import com.cn.fdapfe.biz.domain.FaultDiagnosisModel;
import com.cn.fdapfe.biz.service.IFaultDiagnosisModelService;

/**
 * 故障诊断算法模型管理Service业务层处理
 * 
 * @author Allem
 * @date 2025-03-07
 */
@Service
public class FaultDiagnosisModelServiceImpl implements IFaultDiagnosisModelService 
{
    @Autowired
    private FaultDiagnosisModelMapper faultDiagnosisModelMapper;

    /**
     * 查询故障诊断算法模型管理
     * 
     * @param id 故障诊断算法模型管理主键
     * @return 故障诊断算法模型管理
     */
    @Override
    public FaultDiagnosisModel selectFaultDiagnosisModelById(Long id)
    {
        return faultDiagnosisModelMapper.selectFaultDiagnosisModelById(id);
    }

    /**
     * 查询故障诊断算法模型管理列表
     * 
     * @param faultDiagnosisModel 故障诊断算法模型管理
     * @return 故障诊断算法模型管理
     */
    @Override
    public List<FaultDiagnosisModel> selectFaultDiagnosisModelList(FaultDiagnosisModel faultDiagnosisModel)
    {
        return faultDiagnosisModelMapper.selectFaultDiagnosisModelList(faultDiagnosisModel);
    }

    /**
     * 新增故障诊断算法模型管理
     * 
     * @param faultDiagnosisModel 故障诊断算法模型管理
     * @return 结果
     */
    @Override
    public int insertFaultDiagnosisModel(FaultDiagnosisModel faultDiagnosisModel)
    {
        faultDiagnosisModel.setCreateTime(DateUtils.getNowDate());
        return faultDiagnosisModelMapper.insertFaultDiagnosisModel(faultDiagnosisModel);
    }

    /**
     * 修改故障诊断算法模型管理
     * 
     * @param faultDiagnosisModel 故障诊断算法模型管理
     * @return 结果
     */
    @Override
    public int updateFaultDiagnosisModel(FaultDiagnosisModel faultDiagnosisModel)
    {
        faultDiagnosisModel.setUpdateTime(DateUtils.getNowDate());
        return faultDiagnosisModelMapper.updateFaultDiagnosisModel(faultDiagnosisModel);
    }

    /**
     * 批量删除故障诊断算法模型管理
     * 
     * @param ids 需要删除的故障诊断算法模型管理主键
     * @return 结果
     */
    @Override
    public int deleteFaultDiagnosisModelByIds(Long[] ids)
    {
        return faultDiagnosisModelMapper.deleteFaultDiagnosisModelByIds(ids);
    }

    /**
     * 删除故障诊断算法模型管理信息
     * 
     * @param id 故障诊断算法模型管理主键
     * @return 结果
     */
    @Override
    public int deleteFaultDiagnosisModelById(Long id)
    {
        return faultDiagnosisModelMapper.deleteFaultDiagnosisModelById(id);
    }

    @Override
    public List<Map<String, Object>> getOptions() {
        return faultDiagnosisModelMapper.getOptions();
    }
}
